@@ -16,14 +16,12 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
 from paging.helpers import paginate as paginate_func
 from sentry.conf import settings
-from sentry.plugins import plugins
 from sentry.utils import json
 from sentry.utils.dates import utc_to_local, local_to_utc
 from templatetag_sugar.register import tag
 from templatetag_sugar.parser import Name, Variable, Constant, Optional
 
 import datetime
-import logging
 
 register = template.Library()
 
@@ -52,7 +50,7 @@ def subtract(value, amount):
 
 @register.filter
 def has_charts(group):
-    from sentry.utils.charts import has_charts
+    from sentry.utils.db import has_charts
     if hasattr(group, '_state'):
         db = group._state.db
     else:
@@ -133,86 +131,6 @@ def sentry_version():
     return sentry.VERSION
 
 
-@register.filter
-def get_actions(group, request):
-    action_list = []
-    for inst in plugins.all():
-        try:
-            action_list = inst.actions(request, group, action_list)
-        except Exception, e:
-            logger = logging.getLogger('sentry.plugins')
-            logger.error('Error processing actions() on %r: %s', inst.__class__, e, extra={
-                'request': request,
-            }, exc_info=True)
-
-    for action in action_list:
-        yield action[0], action[1], request.path == action[1]
-
-
-@register.filter
-def get_panels(group, request):
-    panel_list = []
-    for inst in plugins.all():
-        try:
-            panel_list = inst.panels(request, group, panel_list)
-        except Exception, e:
-            logger = logging.getLogger('sentry.plugins')
-            logger.error('Error processing panels() on %r: %s', inst.__class__, e, extra={
-                'request': request,
-            }, exc_info=True)
-
-    for panel in panel_list:
-        yield panel[0], panel[1], request.path == panel[1]
-
-
-@register.filter
-def get_widgets(group, request):
-    for inst in plugins.all():
-        try:
-            resp = inst.widget(request, group)
-            if resp:
-                resp = resp.render(request)
-        except Exception, e:
-            logger = logging.getLogger('sentry.plugins')
-            logger.error('Error processing widget() on %r: %s', inst.__class__, e, extra={
-                'request': request,
-            }, exc_info=True)
-            continue
-        if resp:
-            yield resp
-
-
-@register.filter
-def get_tags(group, request):
-    tag_list = []
-    for inst in plugins.all():
-        try:
-            tag_list = inst.tags(request, group, tag_list)
-        except Exception, e:
-            logger = logging.getLogger('sentry.plugins')
-            logger.error('Error processing tags() on %r: %s', inst.__class__, e, extra={
-                'request': request,
-            }, exc_info=True)
-
-    for tag in tag_list:
-        yield tag
-
-
-@register.simple_tag
-def handle_before_events(request, event_list):
-    if not hasattr(event_list, '__iter__'):
-        event_list = [event_list]
-    for inst in plugins.all():
-        try:
-            inst.before_events(request, event_list)
-        except Exception, e:
-            logger = logging.getLogger('sentry.plugins')
-            logger.error('Error processing before_events() on %r: %s', inst.__class__, e, extra={
-                'request': request,
-            }, exc_info=True)
-    return ''
-
-
 @register.filter
 def timesince(value):
     from django.template.defaultfilters import timesince
